@@ -159,6 +159,9 @@ class ResourceSpec:
 
         return ResourceSpec(cpu=values["cpu"], memory=values["memory"])
 
+    def to_dict(self):
+        return {"cpu": self.cpu, "memory": self.memory}
+
 
 @dataclass
 class NodeAffinityConfig:
@@ -171,9 +174,10 @@ class NodeAffinityConfig:
         # Make (deep) copy to keep original defaults
         values = copy.deepcopy(values)
 
-        return Resources(
-            limits=ResourceSpec.from_dict(values.get("limits", {})),
-            requests=ResourceSpec.from_dict(values.get("requests", {})),
+        return NodeAffinityConfig(
+            key=values['key'],
+            operator=values['operator'],
+            values=values['values']
         )
 
 
@@ -258,7 +262,7 @@ class KubernetesJobConfig:
             + self.scheduler_config.mount_points
             + self.simulation_config.mount_points
         ):
-            if mount_point not in mount_points and mount_point.name != 'shared-data':
+            if mount_point not in mount_points and mount_point.local_path != 'shared-data':
                 mount_points.append(mount_point)
         return mount_points
 
@@ -280,6 +284,7 @@ class KubernetesJobConfig:
                 HostAlias(ip_address, hostnames)
                 for ip_address, hostnames in cfg.get("HOST_ALIASES", {}).items()
             ],
+            annotations=[Label(name, value) for name, value in cfg.get("ANNOTATIONS", {}).items()],
             regcred_secret_name=cfg.get("regcred_secret_name", None),
             node_affinity=NodeAffinityConfig(**cfg["node_affinity"])
             if "node_affinity" in cfg
